@@ -69,6 +69,7 @@ def load_data(name='vdu_signals'):
     if name == 'vdu_signals':
         DATA_PATH = os.path.join(current_dir, 'data/vdu_signals.npy')
         if not os.path.isfile(DATA_PATH):
+            os.mkdir(os.path.join(current_dir, 'data/'))
             get_data(current_dir)
         return np.load(DATA_PATH)
     else:
@@ -563,13 +564,14 @@ class CLASSIX:
         
         # else:
             # print("clusters merging initialize...")
-            self.merge_groups, self.connected_pairs = fast_agglomerate(data, splist, radius, method, scale=self.scale)
+            # self.merge_groups, self.connected_pairs = fast_agglomerate(data, splist, radius, method, scale=self.scale)
             # self.check_labels = labels
             # reassign lalels, start from 0, since the cluster number not start with 0.
 
             # we employ an intutive and simple way to implement merging groups, resulting in a fast clustering
             # self.merge_groups = merge_pairs(self.connected_pairs)
-            
+        
+        self.merge_groups, self.connected_pairs = fast_agglomerate(data, splist, radius, method, scale=self.scale)
         maxid = max(labels) + 1
         
         # after this step, the connected pairs (groups) will be transformed into merged clusters, 
